from datetime import date
import scrapy


# scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=3 -a day=22

import re

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = "noticias"
	def start_requests(self):
		self.year = getattr(self, 'year', None)
		self.month = getattr(self, 'month', None)
		self.day = getattr(self, 'day', None)
		self.baseURL='http://www.jornada.unam.mx/'+self.year+'/'+self.month.zfill(2)+'/'+self.day.zfill(2)+'/'
		
		comparison_date = date(2009, 2, 15)
		requested_date = date(int(self.year), int(self.month), int(self.day))

		section_list = ['opinion', 'politica', 'economia', 'mundo', 'estados', 'ciencias',
						'capital', 'sociedad', 'cultura', 'espectaculos', 'deportes']

		for section in section_list:
			# para la fecha 2009/02/15 o menores, se tiene una estructura determinada de pagina
			# para las fechas mayores a esa la estructura cambia
			if ( requested_date <= comparison_date ):
				yield scrapy.Request(url=self.baseURL+section, callback=self.parse)
			else:
				yield scrapy.Request(url=self.baseURL+section, callback=self.parse_2)


	def parse(self, response):
		if ( response.url[:response.url.rfind('/')+1] == self.baseURL ):   # verifica que se conserva la misma URL base
			section = response.url[response.url.rfind('/')+1:]
			if ( section == 'opinion' ):   # la seccion 'opinion' tiene una estructura diferente a las otras
				path_list = ['//*[@id="columnas"]/p/a/@href',
							 '//*[@id="opinion"]/p/a/@href']
			else:
				path_list = ['//*[@id="article_list"]/h2/a/@href',
						 	 '//*[@id="article_list"]/h3/a/@href']

			for path in path_list:
				for link in response.xpath(path).extract():
					yield scrapy.Request(url=self.baseURL+link, callback=self.parse_item)


	def parse_2(self, response):
		if ( response.url[:response.url.rfind('/')+1] == self.baseURL ):
			path_list = ['//*[@class="itemfirst"]/div/a/@href', '//*[@class="item start"]/div/a/@href',
						 '//*[@class="item"]/div/a/@href']

			for path in path_list:
				for link in response.xpath(path).extract():
					yield scrapy.Request(url=self.baseURL+link, callback=self.parse_item_2)


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''
		item['date'] = self.year+'-'+self.month.zfill(2)+'-'+self.day.zfill(2)
		title = response.xpath('//*[@class="documentContent"]/h1[@class="title"]/text()').extract()
		if ( len(title) > 0 ):
			item['title'] = title[0]
		else:
			item['title'] = response.xpath('//*[@class="documentContent"]/h1/text()').extract_first()
		item['topic'] = response.xpath('//*[@id="portal-breadcrumbs"]/a[2]/text()').extract()
		for paragraph in response.xpath('//*[@class="documentContent"]/p/text()').extract():
			text += paragraph
		item['text'] = text
		item['url'] = response.url
		# print item['title']
		yield item


	def parse_item_2(self, response):
		item = NoticiasItem()
		text = ''
		path_list = ['//*[@class="col"]/p', '//*[@class="col col1"]/p', '//*[@class="col col2"]/p']
		
		item['date'] = self.year+'-'+self.month.zfill(2)+'-'+self.day.zfill(2)
		item['title'] = remove_tags(response.xpath('//*[@class="cabeza"]').extract_first())
		item['topic'] = response.xpath('//*[@class="breadcrumb gui"]/span[2]/a/text()').extract()

		for path in path_list: 
			for paragraph in response.xpath(path).extract():
				text += remove_tags(paragraph)
		item['text'] = text
		item['url'] = response.url
		# print item['title']
		yield item

