import scrapy

#scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=3 -a day=22

import re


TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = "noticias"
	def start_requests(self):
		year = getattr(self, 'year', None)
		month = getattr(self, 'month', None)
		day = getattr(self, 'day', None)
		self.baseURL='http://lajornadasanluis.com.mx/'+year+'/'+month+'/'+day
		urls = [
			self.baseURL,
                ]
		for url in urls:
			yield scrapy.Request(url=url, callback=self.parse)


	def parse(self, response):
		pagination = response.xpath('//div[@class="pages"]/a/@href').extract()
		if ( len(pagination) > 0 ):
			pagination = pagination[-1].strip('/')
			pages = int(pagination[pagination.rfind('/')+1:])
			for page in range(0,pages):
				if ( page == 0 ):
					yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
				else:
					yield scrapy.Request(url=self.baseURL+'/page/'+str(page+1), callback=self.parse_page)
		else:
			yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)


	def parse_page(self, response):
		for link in response.xpath('//*[@class="post-title"]/h2/a/@href').extract():
			yield scrapy.Request(url=link, callback=self.parse_item)


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''
		item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
		item['title'] = response.css('h1.entry-title::text').extract_first()
		item['topic'] = response.xpath('//ul[@class="post-categories"]/li/a/text()').extract()
		for paragraph in response.xpath('//p[@style="text-align: justify;"]/text()').extract():
			text += remove_tags(paragraph) + '\n'
		item['text'] = text
		item['url'] = response.url
		# print item['title']
		yield item

